@@ -27,7 +27,7 @@ from .overview import Overview, OverviewState, PreviewState
 # TODO builtin frame/stack explorer? from objexplore import stackexplore
 
 
-version = "1.5.4"
+version = "1.5.5"
 console = Console()
 EDITOR = os.environ.get("EDITOR")
 
@@ -79,7 +79,8 @@ class ObjExploreApp:
                     else:
                         raise err
                 except StopIteration:
-                    res = self.explorer.selected_object
+                    if key == "r":
+                        res = self.explorer.selected_object.obj
                     break
 
         # Unhide the cursor
@@ -329,7 +330,10 @@ class ObjExploreApp:
             elif self.overview.preview_state == PreviewState.repr:
                 printable = self.explorer.selected_object.obj
 
-            elif self.overview.preview_state == PreviewState.source and self.explorer.selected_object._source:
+            elif (
+                self.overview.preview_state == PreviewState.source
+                and self.explorer.selected_object._source
+            ):
                 printable = self.explorer.selected_object.get_source(fullscreen=True)
 
             else:
